@@ -2,17 +2,13 @@
 import os
 import sys
 from setuptools import setup
-from os import path
 
 # version of pycurl-client, should match current DBS release tag
-package_version = "3.17.0.2"
+package_version = "3.17.1"
 
 # Requirements file for pip dependencies
 requirements = "requirements.txt"
 
-this_directory = path.abspath(path.dirname(__file__))
-with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
-    long_description = f.read()
 
 def parse_requirements(requirements_file):
     """
@@ -36,9 +32,7 @@ setup(name="dbs3-client",
                 'dbsClient.exceptions'],
       package_dir={'': 'src/python'},
       install_requires=parse_requirements(requirements),
-      long_description=long_description,
-      long_description_content_type='text/markdown',
-      url="https://github.com/dmwm/DBSClient",
+      url="https://github.com/dmwm/DBSClient/tree/3.17.1",
       license="Apache License, Version 2.0",
       )
 
